#
# spec file for package python-Werkzeug
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python-Werkzeug
Version:        0.10.4
Release:        5.2
Url:            http://werkzeug.pocoo.org/
Summary:        The Swiss Army knife of Python web development
License:        BSD-3-Clause
Group:          Development/Languages/Python
Source:         http://pypi.python.org/packages/source/W/Werkzeug/Werkzeug-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-Sphinx
BuildRequires:  python-devel
BuildRequires:  python-nose
BuildRequires:  python-setuptools
Provides:       python-werkzeug = %{version}
Obsoletes:      python-werkzeug < %{version}
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Werkzeug started as simple collection of various utilities for WSGI
applications and has become one of the most advanced WSGI utility
modules.  It includes a powerful debugger, full featured request and
response objects, HTTP utilities to handle entity tags, cache control
headers, HTTP dates, cookie handling, file uploads, a powerful URL
routing system and a bunch of community contributed addon modules.

Werkzeug is unicode aware and doesn't enforce a specific template
engine, database adapter or anything else.  It doesn't even enforce
a specific way of handling requests and leaves all that up to the
developer. It's most useful for end user applications which should work
on as many server environments as possible (such as blogs, wikis,
bulletin boards, etc.).

%package doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Requires:       %{name} = %{version}

%description doc
Documentation and examples for %{name}.

%prep
%setup -q -n Werkzeug-%{version}
sed -i "s/\r//" LICENSE # Fix wrong EOL-encoding
sed -i "1d" examples/manage-{i18nurls,simplewiki,shorty,couchy,cupoftee,webpylike,plnt,coolmagic}.py # Fix non-executable scripts

%build
python setup.py build
cd docs && make html && rm -rf _build/html/.buildinfo # Build HTML Documentation

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root,-)
%doc AUTHORS LICENSE CHANGES
%{python_sitelib}/*

%files doc
%defattr(-,root,root,-)
%doc docs/_build/html examples

%changelog
* Mon Jun 22 2015 tbechtold@suse.com
- update to 0.10.4:
  - Re-release of 0.10.3 with packaging artifacts manually removed.
  - Re-release of 0.10.2 without packaging artifacts.
  - Fixed issue where ``empty`` could break third-party libraries that relied on
    keyword arguments (pull request ``#675``)
  - Improved ``Rule.empty`` by providing a ```get_empty_kwargs`` to allow setting
    custom kwargs without having to override entire ``empty`` method. (pull
    request ``#675``)
  - Fixed ```extra_files``` parameter for reloader to not cause startup
    to crash when included in server params
  - Using `MultiDict` when building URLs is now not supported again. The behavior
    introduced several regressions.
  - Fix performance problems with stat-reloader (pull request ``#715``).
  - Fixed regression with multiple query values for URLs (pull request ``#667``).
  - Fix issues with eventlet's monkeypatching and the builtin server (pull
    request ``#663``).
  - Changed the error handling of and improved testsuite for the caches in
    ``contrib.cache``.
  - Fixed a bug on Python 3 when creating adhoc ssl contexts, due to `sys.maxint`
    not being defined.
  - Fixed a bug on Python 3, that caused
    :func:`~werkzeug.serving.make_ssl_devcert` to fail with an exception.
  - Added exceptions for 504 and 505.
  - Added support for ChromeOS detection.
  - Added UUID converter to the routing system.
  - Added message that explains how to quit the server.
  - Fixed a bug on Python 2, that caused ``len`` for
    :class:`werkzeug.datastructures.CombinedMultiDict` to crash.
  - Added support for stdlib pbkdf2 hmac if a compatible digest
    is found.
  - Ported testsuite to use ``py.test``.
  - Minor optimizations to various middlewares (pull requests ``#496`` and
    ``#571``).
  - Use stdlib ``ssl`` module instead of ``OpenSSL`` for the builtin server
    (issue ``#434``). This means that OpenSSL contexts are not supported anymore,
    but instead ``ssl.SSLContext`` from the stdlib.
  - Allow protocol-relative URLs when building external URLs.
  - Fixed Atom syndication to print time zone offset for tz-aware datetime
    objects (pull request ``#254``).
  - Improved reloader to track added files and to recover from broken
    sys.modules setups with syntax errors in packages.
  - ``cache.RedisCache`` now supports arbitrary ``**kwargs`` for the redis
    object.
  - ``werkzeug.test.Client`` now uses the original request method when resolving
    307 redirects (pull request ``#556``).
  - ``werkzeug.datastructures.MIMEAccept`` now properly deals with mimetype
    parameters (pull request ``#205``).
  - ``werkzeug.datastructures.Accept`` now handles a quality of ``0`` as
    intolerable, as per RFC 2616 (pull request ``#536``).
  - ``werkzeug.urls.url_fix`` now properly encodes hostnames with ``idna``
    encoding (issue ``#559``). It also doesn't crash on malformed URLs anymore
    (issue ``#582``).
  - ``werkzeug.routing.MapAdapter.match`` now recognizes the difference between
    the path ``/`` and an empty one (issue ``#360``).
  - The interactive debugger now tries to decode non-ascii filenames (issue
    ``#469``).
  - Increased default key size of generated SSL certificates to 1024 bits (issue
    ``#611``).
  - Added support for specifying a ``Response`` subclass to use when calling
    :func:`~werkzeug.utils.redirect`\ .
  - ``werkzeug.test.EnvironBuilder`` now doesn't use the request method anymore
    to guess the content type, and purely relies on the ``form``, ``files`` and
  ``input_stream`` properties (issue ``#620``).
  - Added Symbian to the user agent platform list.
  - Fixed make_conditional to respect automatically_set_content_length
  - Unset ``Content-Length`` when writing to response.stream (issue ``#451``)
  - ``wrappers.Request.method`` is now always uppercase, eliminating
    inconsistencies of the WSGI environment (issue ``647``).
  - ``routing.Rule.empty`` now works correctly with subclasses of ``Rule`` (pull
    request ``#645``).
  - Made map updating safe in light of concurrent updates.
  - Allow multiple values for the same field for url building (issue ``#658``).
  - Fix unicode problems in ``werkzeug.debug.tbtools``.
  - Fix Python 3-compatibility problems in ``werkzeug.posixemulation``.
  - Backport fix of fatal typo for ``ImmutableList`` (issue ``#492``).
  - Make creation of the cache dir for ``FileSystemCache`` atomic (issue
    ``#468``).
  - Use native strings for memcached keys to work with Python 3 client (issue
    ``#539``).
  - Fix charset detection for ``werkzeug.debug.tbtools.Frame`` objects (issues
    ``#547`` and ``#532``).
  - Fix ``AttributeError`` masking in ``werkzeug.utils.import_string`` (issue
    ``#182``).
  - Explicitly shut down server (issue ``#519``).
  - Fix timeouts greater than 2592000 being misinterpreted as UNIX timestamps in
    ``werkzeug.contrib.cache.MemcachedCache`` (issue ``#533``).
  - Fix bug where ``werkzeug.exceptions.abort`` would raise an arbitrary subclass
    of the expected class (issue ``#422``).
  - Fix broken ``jsrouting`` (due to removal of ``werkzeug.templates``)
  - ``werkzeug.urls.url_fix`` now doesn't crash on malformed URLs anymore, but
    returns them unmodified. This is a cheap workaround for ``#582``, the proper
    fix is included in version 0.10.
  - The repr of ``werkzeug.wrappers.Request`` doesn't crash on non-ASCII-values
    anymore (pull request ``#466``).
  - Fix bug in ``cache.RedisCache`` when combined with ``redis.StrictRedis``
    object (pull request ``#583``).
  - The ``qop`` parameter for ``WWW-Authenticate`` headers is now always quoted,
    as required by RFC 2617 (issue ``#633``).
  - Fix bug in ``werkzeug.contrib.cache.SimpleCache`` with Python 3 where add/set
    may throw an exception when pruning old entries from the cache (pull request
    ``#651``).
* Fri Jul 18 2014 toddrme2178@gmail.com
- Update to 0.9.6
  - Added a safe conversion for IRI to URI conversion and use that
    internally to work around issues with spec violations for
    protocols such as ``itms-service``.
- Update to 0.9.5
  - Forward charset argument from request objects to the environ
    builder.
  - Fixed error handling for missing boundaries in multipart data.
  - Fixed session creation on systems without ``os.urandom()``.
  - Fixed pluses in dictionary keys not being properly URL encoded.
  - Fixed a problem with deepcopy not working for multi dicts.
  - Fixed a double quoting issue on redirects.
  - Fixed a problem with unicode keys appearing in headers on 2.x.
  - Fixed a bug with unicode strings in the test builder.
  - Fixed a unicode bug on Python 3 in the WSGI profiler.
  - Fixed an issue with the safe string compare function on
    Python 2.7.7 and Python 3.4.
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Tue Sep  3 2013 dmueller@suse.com
- update to 0.9.4:
  - Fixed an issue with Python 3.3 and an edge case in cookie parsing.
  - Fixed decoding errors not handled properly through the WSGI
    decoding dance.
  - Fixed URI to IRI conversion incorrectly decoding percent signs.
  - Restored beahvior of the ``data`` descriptor of the request class to pre 0.9
    behavior.  This now also means that ``.data`` and ``.get_data()`` have
    different behavior.  New code should use ``.get_data()`` always.
    In addition to that there is now a flag for the ``.get_data()`` method that
    controls what should happen with form data parsing and the form parser will
    honor cached data.  This makes dealing with custom form data more consistent.
  - Added `unsafe` parameter to :func:`~werkzeug.urls.url_quote`.
  - Fixed an issue with :func:`~werkzeug.urls.url_quote_plus` not quoting
    `'+'` correctly.
  - Ported remaining parts of :class:`~werkzeug.contrib.RedisCache` to
    Python 3.3.
  - Ported remaining parts of :class:`~werkzeug.contrib.MemcachedCache` to
    Python 3.3
  - Fixed a deprecation warning in the contrib atom module.
  - Fixed a regression with setting of content types through the
    headers dictionary instead with the content type parameter.
  - Use correct name for stdlib secure string comparision function.
  - Fixed a wrong reference in the docstring of
    :func:`~werkzeug.local.release_local`.
  - Fixed an `AttributeError` that sometimes occurred when accessing the
    :attr:`werkzeug.wrappers.BaseResponse.is_streamed` attribute.
  - Fixed an issue with integers no longer being accepted in certain
    parts of the routing system or URL quoting functions.
  - Fixed an issue with `url_quote` not producing the right escape
    codes for single digit codepoints.
  - Fixed an issue with :class:`~werkzeug.wsgi.SharedDataMiddleware` not
    reading the path correctly and breaking on etag generation in some
    cases.
  - Properly handle `Expect: 100-continue` in the development server
    to resolve issues with curl.
  - Automatically exhaust the input stream on request close.  This should
    fix issues where not touching request files results in a timeout.
  - Fixed exhausting of streams not doing anything if a non-limited
    stream was passed into the multipart parser.
  - Raised the buffer sizes for the multipart parser.
  - Added support for :meth:`~werkzeug.wsgi.LimitedStream.tell`
    on the limited stream.
  - :class:`~werkzeug.datastructures.ETags` now is nonzero if it
    contains at least one etag of any kind, including weak ones.
  - Added a workaround for a bug in the stdlib for SSL servers.
  - Improved SSL interface of the devserver so that it can generate
    certificates easily and load them from files.
  - Refactored test client to invoke the open method on the class
    for redirects.  This makes subclassing more powerful.
  - :func:`werkzeug.wsgi.make_chunk_iter` and
    :func:`werkzeug.wsgi.make_line_iter` now support processing of
    iterators and streams.
  - URL generation by the routing system now no longer quotes
    ``+``.
  - URL fixing now no longer quotes certain reserved characters.
  - The :func:`werkzeug.security.generate_password_hash` and
    check functions now support any of the hashlib algorithms.
  - `wsgi.get_current_url` is now ascii safe for browsers sending
    non-ascii data in query strings.
  - improved parsing behavior for :func:`werkzeug.http.parse_options_header`
  - added more operators to local proxies.
  - added a hook to override the default converter in the routing
    system.
  - The description field of HTTP exceptions is now always escaped.
    Use markup objects to disable that.
  - Added number of proxy argument to the proxy fix to make it more
    secure out of the box on common proxy setups.  It will by default
    no longer trust the x-forwarded-for header as much as it did
    before.
  - Added support for fragment handling in URI/IRI functions.
  - Added custom class support for :func:`werkzeug.http.parse_dict_header`.
  - Renamed `LighttpdCGIRootFix` to `CGIRootFix`.
  - Always treat `+` as safe when fixing URLs as people love misusing them.
  - Added support to profiling into directories in the contrib profiler.
  - The escape function now by default escapes quotes.
  - Changed repr of exceptions to be less magical.
  - Simplified exception interface to no longer require environmnts
    to be passed to recieve the response object.
  - Added sentinel argument to IterIO objects.
  - Added pbkdf2 support for the security module.
  - Added a plain request type that disables all form parsing to only
    leave the stream behind.
  - Removed support for deprecated `fix_headers`.
  - Removed support for deprecated `header_list`.
  - Removed support for deprecated parameter for `iter_encoded`.
  - Removed support for deprecated non-silent usage of the limited
    stream object.
  - Removed support for previous dummy `writable` parameter on
    the cached property.
  - Added support for explicitly closing request objects to close
    associated resources.
  - Conditional request handling or access to the data property on responses no
    longer ignores direct passthrough mode.
  - Removed werkzeug.templates and werkzeug.contrib.kickstart.
  - Changed host lookup logic for forwarded hosts to allow lists of
    hosts in which case only the first one is picked up.
  - Added `wsgi.get_query_string`, `wsgi.get_path_info` and
    `wsgi.get_script_name` and made the `wsgi.pop_path_info` and
    `wsgi.peek_path_info` functions perform unicode decoding.  This
    was necessary to avoid having to expose the WSGI encoding dance
    on Python 3.
  - Added `content_encoding` and `content_md5` to the request object's
    common request descriptor mixin.
  - added `options` and `trace` to the test client.
  - Overhauled the utilization of the input stream to be easier to use
    and better to extend.  The detection of content payload on the input
    side is now more compliant with HTTP by detecting off the content
    type header instead of the request method.  This also now means that
    the stream property on the request class is always available instead
    of just when the parsing fails.
  - Added support for using :class:`werkzeug.wrappers.BaseResponse` in a with
    statement.
  - Changed `get_app_iter` to fetch the response early so that it does not
    fail when wrapping a response iterable.  This makes filtering easier.
  - Introduced `get_data` and `set_data` methods for responses.
  - Introduced `get_data` for requests.
  - Soft deprecated the `data` descriptors for request and response objects.
  - Added `as_bytes` operations to some of the headers to simplify working
    with things like cookies.
  - Made the debugger paste tracebacks into github's gist service as
    private pastes.
* Mon Mar 12 2012 saschpe@gmx.de
- Update to version 0.8.3:
  - Fixed another issue with :func:`werkzeug.wsgi.make_line_iter`
    where lines longer than the buffer size were not handled
    properly.
  - Restore stdout after debug console finished executing so
    that the debugger can be used on GAE better.
  - Fixed a bug with the redis cache for int subclasses
    (affects bool caching).
  - Fixed an XSS problem with redirect targets coming from
    untrusted sources.
- Changes from version 0.8.2:
  - Fixed a problem with request handling of the builtin server
    not repsonding to socket errors properly.
  - The routing request redirect exception's code attribute is now
    used properly.
  - Fixed a bug with shutdowns on Windows.
  - Fixed a few unicode issues with non-ascii characters being
    hardcoded in URL rules.
  - Fixed two property docstrings being assigned to fdel instead
    of ``__doc__``.
  - Fixed an issue where CRLF line endings could be split into two
    by the line iter function, causing problems with multipart file
    uploads.
* Thu Nov 10 2011 saschpe@suse.de
- Update to version 0.8.1:
  * Fixed an issue with the memcache not working properly.
  * Fixed an issue for Python 2.7.1 and higher that broke
    copying of multidicts with :func:`copy.copy`.
  * Changed hashing methodology of immutable ordered multi dicts
    for a potential problem with alternative Python implementations.
- Changes from version 0.8:
  * Removed data structure specific KeyErrors for a general
    purpose :exc:`~werkzeug.exceptions.BadRequestKeyError`.
  * Documented :meth:`werkzeug.wrappers.BaseRequest._load_form_data`.
  * The routing system now also accepts strings instead of
    dictionaries for the `query_args` parameter since we're only
    passing them through for redirects.
  * Werkzeug now automatically sets the content length immediately when
    the :attr:`~werkzeug.wrappers.BaseResponse.data` attribute is set
    for efficiency and simplicity reasons.
  * The routing system will now normalize server names to lowercase.
  * The routing system will no longer raise ValueErrors in case the
    configuration for the server name was incorrect.  This should make
    deployment much easier because you can ignore that factor now.
  * Fixed a bug with parsing HTTP digest headers.  It rejected headers
    with missing nc and nonce params.
  * Proxy fix now also updates wsgi.url_scheme based on X-Forwarded-Proto.
  * Added support for key prefixes to the redis cache.
  * Added the ability to supress some auto corrections in the wrappers
    that are now controlled via `autocorrect_location_header` and
    `automatically_set_content_length` on the response objects.
  * Werkzeug now uses a new method to check that the length of incoming
    data is complete and will raise IO errors by itself if the server
    fails to do so.
  * :func:`~werkzeug.wsgi.make_line_iter` now requires a limit that is
    not higher than the length the stream can provide.
  * Refactored form parsing into a form parser class that makes it possible
    to hook into individual parts of the parsing process for debugging and
    extending.
  * For conditional responses the content length is no longer set when it
    is already there and added if missing.
  * Immutable datastructures are hashable now.
  * Headers datastructure no longer allows newlines in values to avoid
    header injection attacks.
  * Made it possible through subclassing to select a different remote
    addr in the proxy fix.
  * Added stream based URL decoding.  This reduces memory usage on large
    transmitted form data that is URL decoded since Werkzeug will no longer
    load all the unparsed data into memory.
  * Memcache client now no longer uses the buggy cmemcache module and
    supports pylibmc.  GAE is not tried automatically and the dedicated
    class is no longer necessary.
  * Redis cache now properly serializes data.
  * Removed support for Python 2.4
- Changes from version 0.7.2:
  * Fixed a CSRF problem with the debugger.
  * The debugger is now generating private pastes on lodgeit.
  * If URL maps are now bound to environments the query arguments
    are properly decoded from it for redirects.
* Tue Sep 27 2011 saschpe@suse.de
- Package renamed to python-Werkzeug
- Update to version 0.7.1:
  * Fixed a problem with newer versions of IPython
  * Disabled pyinotify based reloader which does not work reliably.
- Changes from version 0.7.0:
  * Add support for python-libmemcached to the Werkzeug cache abstraction
    layer.
  * improved url_decode and url_encode performance.
  * fixed an issue where the SharedDataMiddleware could cause an
    internal server error on weird paths when loading via pkg_resources.
  * fixed an URL generation bug that caused URLs to be invalid if a
    generated component contains a colon.
  * werkzeug.import_string now works with partially set up
    packages properly.
  * disabled automatic socket swiching for IPv6 on the development
    server due to problems it caused.
  * Werkzeug no longer overrides the Date header when creating a
    conditional HTTP response.
  * The routing system provides a method to retrieve the matching
    methods for a given path.
  * The routing system now accepts a parameter to change the encoding
    error behaviour.
  * The local manager can now accept custom ident functions in the
    constructor that are forwarded to the wrapped local objects.
  * url_unquote_plus now accepts unicode strings again.
  * fixed an issues with the filesystem session support's prune
    function and concurrent usage.
  * fixed a problem with external URL generation discarding the port.
  * added support for pylibmc to the Werkzeug cache abstraction layer.
  * fixed an issue with the new multipart parser that happened when
    a linkebreak happend to be on the chunk limit.
  * cookies are now set properly if ports are in use.  A runtime error
    is raised if one tries to set a cookie for a domain without a dot.
  * fixed an issue with Template.from_file not working for file
    descriptors.
  * reloader can now use inotify to track reloads.  This requires the
    pyinotify library to be installed.
  * See more in file CHANGES...
- Generate HTML documentation with Sphinx
- Don't package PKG-INFO
- BuildRequire python-distribute instead of python-setuptools
* Thu Apr 14 2011 saschpe@suse.de
- Add spec file license header
- Use py_requires
- Moved changelog from spec to changes file
- Corrected RPM groups
* Wed Apr 13 2011 hpj@urpla.net
- Update to 0.6.2
* Fri Mar  5 2010 phalliday@excelsiorsystems.net
- Updating because upstream release of Werkzeug 0.6
* Tue Aug 25 2009 phalliday@excelsiorsystems.net
- Initial package
